==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/it-IT/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Conferma Eliminazione Massiva di Beni',
    'bulk_restore'      => 'Conferma Ripristino Massivo di Beni', 
  'bulk_delete_help'	=> 'Controlla i Beni scelti per l\'eliminazione massiva. Una volta eliminati, i Beni potranno essere ripristinati, ma non saranno più associati agli utenti a cui sono assegnati ora.',
  'bulk_restore_help'	=> 'Esamina i beni da ripristinare qui sotto. Una volta recuperati, i beni non verranno riassegnati agli utenti a cui erano precedentemente assegnati.',
  'bulk_delete_warn'	=> 'Stai per cancellare :asset_count assets.',
  'bulk_restore_warn'	=> 'Stai per ripristinare :asset_count beni.',
    'bulk_update'		=> 'Aggiornamento Massivo Beni',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più beni alla volta. Riempi solo i campi da cambiare. Tutti i campi lasciati vuoti rimarranno invariati. ',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di un bene.|Stai per modificare le proprietà di :asset_count beni.',
    'bulk_update_with_custom_field' => 'Nota che i beni sono di :asset_model_count modelli differenti.',
    'bulk_update_model_prefix' => 'Sui Modelli', 
    'bulk_update_custom_field_unique' => 'Questo è un campo unico e non può essere modificato massivamente.',
    'checkedout_to'		=> 'Assegnato a',
    'checkout_date'		=> 'Data di Assegnazione',
    'checkin_date'		=> 'Data Restituzione',
    'checkout_to'		=> 'Assegnare a',
    'cost'				=> 'Costo Acquisto',
    'create'			=> 'Crea Bene',
    'date'				=> 'Data Acquisto',
    'depreciation'	    => 'Deprezzamento',
    'depreciates_on'	=> 'Deprezza Si',
    'default_location'	=> 'Sede predefinita',
    'default_location_phone' => 'Telefono Sede Predefinita',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'EOL tra:',
    'expected_checkin'  => 'Restituzione Prevista il',
    'expires'			=> 'Scade',
    'fully_depreciated'	=> 'Pienamente Deprezzato',
    'help_checkout'		=> 'Se vuoi assegnare questo Bene subito, scegli "Pronto per Assegnazione" dall\'elenco stati qui sopra. ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'Produttore',
    'model'				=> 'Modello',
    'months'			=> 'mesi',
    'name'				=> 'Nome Bene',
    'notes'				=> 'Note',
    'order'				=> 'Numero Ordine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Gli utenti possono richiedere questo bene',
    'redirect_to_all'   => 'Ritorna a tutti i :type',
    'redirect_to_type'   => 'Vai a :type',
    'redirect_to_checked_out_to'   => 'Vai agli assegnati',
    'select_statustype'	=> 'Selezionare il tipo di stato',
    'serial'			=> 'Seriale',
    'status'			=> 'Stato',
    'tag'				=> 'Etichetta Bene',
    'update'			=> 'Aggiorna Bene',
    'warranty'			=> 'Garanzia',
        'warranty_expires'		=> 'Scadenza Garanzia',
    'years'				=> 'anni',
    'asset_location' => 'Aggiorna Sede del Bene',
    'asset_location_update_default_current' => 'Aggiorna la Sede predefinita E quella attuale',
    'asset_location_update_default' => 'Aggiorna solo la Sede predefinita',
    'asset_location_update_actual' => 'Aggiorna solo la Sede effettiva',
    'asset_not_deployable' => 'Lo stato del bene è "Non Assegnabile". Non puoi fare l\'assegnazione di questo Bene.',
    'asset_not_deployable_checkin' => 'Questo stato è "Non Assegnabile". Usando questo stato, verrà effettuata la restituzione del Bene.',
    'asset_deployable' => 'Lo stato del bene è "Assegnabile". Puoi fare l\'Assegnazione di questo Bene.',
    'processing_spinner' => 'Elaborazione... (Può volerci un po\' su file di grandi dimensioni)',
    'optional_infos'  => 'Informazioni Opzionali',
    'order_details'   => 'Informazioni relative all\'ordine'
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/it-IT/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Conferma Eliminazione Massiva di Beni',
    'bulk_restore'      => 'Conferma Ripristino Massivo di Beni', 
  'bulk_delete_help'	=> 'Controlla i Beni scelti per l\'eliminazione massiva. Una volta eliminati, i Beni potranno essere ripristinati, ma non saranno più associati agli utenti a cui sono assegnati ora.',
  'bulk_restore_help'	=> 'Esamina i beni da ripristinare qui sotto. Una volta recuperati, i beni non verranno riassegnati agli utenti a cui erano precedentemente assegnati.',
  'bulk_delete_warn'	=> 'Stai per cancellare :asset_count assets.',
  'bulk_restore_warn'	=> 'Stai per ripristinare :asset_count beni.',
    'bulk_update'		=> 'Aggiornamento Massivo Beni',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più beni alla volta. Riempi solo i campi da cambiare. Tutti i campi lasciati vuoti rimarranno invariati. ',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di un bene.|Stai per modificare le proprietà di :asset_count beni.',
    'bulk_update_with_custom_field' => 'Nota che i beni sono di :asset_model_count modelli differenti.',
    'bulk_update_model_prefix' => 'Sui Modelli', 
    'bulk_update_custom_field_unique' => 'Questo è un campo unico e non può essere modificato massivamente.',
    'checkedout_to'		=> 'Assegnato a',
    'checkout_date'		=> 'Data di Assegnazione',
    'checkin_date'		=> 'Data Restituzione',
    'checkout_to'		=> 'Assegnare a',
    'cost'				=> 'Costo Acquisto',
    'create'			=> 'Crea Bene',
    'date'				=> 'Data Acquisto',
    'depreciation'	    => 'Deprezzamento',
    'depreciates_on'	=> 'Deprezza Si',
    'default_location'	=> 'Sede predefinita',
    'default_location_phone' => 'Telefono Sede Predefinita',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'EOL tra:',
    'expected_checkin'  => 'Restituzione Prevista il',
    'expires'			=> 'Scade',
    'fully_depreciated'	=> 'Pienamente Deprezzato',
    'help_checkout'		=> 'Se vuoi assegnare questo Bene subito, scegli "Pronto per Assegnazione" dall\'elenco stati qui sopra. ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'Produttore',
    'model'				=> 'Modello',
    'months'			=> 'mesi',
    'name'				=> 'Nome Bene',
    'notes'				=> 'Note',
    'order'				=> 'Numero Ordine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Gli utenti possono richiedere questo bene',
    'redirect_to_all'   => 'Ritorna a tutti i :type',
    'redirect_to_type'   => 'Vai a :type',
    'redirect_to_checked_out_to'   => 'Vai agli assegnati',
    'select_statustype'	=> 'Selezionare il tipo di stato',
    'serial'			=> 'Seriale',
    'status'			=> 'Stato',
    'tag'				=> 'Etichetta Bene',
    'update'			=> 'Aggiorna Bene',
    'warranty'			=> 'Garanzia',
        'warranty_expires'		=> 'Scadenza Garanzia',
    'years'				=> 'anni',
    'asset_location' => 'Aggiorna Sede del Bene',
    'asset_location_update_default_current' => 'Aggiorna la Sede predefinita E quella attuale',
    'asset_location_update_default' => 'Aggiorna solo la Sede predefinita',
    'asset_location_update_actual' => 'Aggiorna solo la Sede effettiva',
    'asset_not_deployable' => 'Lo stato del bene è "Non Assegnabile". Non puoi fare l\'assegnazione di questo Bene.',
    'asset_not_deployable_checkin' => 'Questo stato è "Non Assegnabile". Usando questo stato, verrà effettuata la restituzione del Bene.',
    'asset_deployable' => 'Lo stato del bene è "Assegnabile". Puoi fare l\'Assegnazione di questo Bene.',
    'processing_spinner' => 'Elaborazione... (Può volerci un po\' su file di grandi dimensioni)',
    'optional_infos'  => 'Informazioni Opzionali',
    'order_details'   => 'Informazioni relative all\'ordine',
    'calc_eol'    => 'Se viene annullata la data di EOL, usa il calcolo automatico in base alla data d\'acquisto e al tasso di EOL.',
];
